/*
 * cmdFile is used below since CCS/project wizard does not allow the
 * use of linkerCommandFile like we'd like.  The workaround is to provide
 * the .cmd file in the fileList[] array and set linkerCommandFile to "".
 */

/*
 *  Remove C6472 and TI816X from generic C6000, since these will be covered by
 *  other filters.
 */
var filterGenericC6000 = [
    {deviceFamily: "C6000",
     deviceId: "~.*(TMS320C670|TMS320C671|TMS320C672|DSK6713|GenericC62xxDevice|GenericC64xxDevice|GenericC67xxDevice|GenericC67xPlusDevice|C641|C6472|TI816x).*",
     toolChain: "TI"},
];

/*
 *  Remove TI816x from generic ARM, since it will be covered by
 *  other filters.
 */
var filterGenericARM = [
    {deviceFamily:"ARM", deviceId: "~.*(Cortex A|TM4C|TM4E|TM4L|LM3|F28M3|LM4|RM4|TMS570LS|ARM7|ARM11|Generic|EVMDMRX45X|CC2538|TMS470M|DM350|DM357|DM368|TI816x).*", toolChain: "TI"},
];

var filterA8 = [
    {deviceFamily:"ARM", deviceId: ".*(Cortex A).*", toolChain:"TI"},
];

var filterA8GNU = [
    {deviceFamily:"ARM", deviceId: ".*(Cortex A).*", toolChain:"GNU"},
];

/*
 * Filter on ~F28M3 since filtering for TMS320C/F prefixes isn't
 * working.  We need to get a precise deviceId list from Toronto so we can
 * determine how to make these filters more reliable and sustainable.
 */
var filterC28 = [
    {deviceFamily: "C2000", deviceId: "~.*(F28M3|Generic|G00883).*", toolChain: "TI"},
];

var defaultFilterMSP430 = [
    {deviceId: "MSP430F5.*", toolChain: "TI"},
    {deviceId: "MSP430F6.*", toolChain: "TI"},
    {deviceId: "MSP430BT.*", toolChain: "TI"},
    {deviceId: "CC430.*",    toolChain: "TI"},
];


var filterMSP430 = [
];

var filterStellaris = [
    {deviceFamily:"ARM", deviceId:".*LM3.*", toolChain:"TI"},
];

var filterStellarisM3GNU = [
    {deviceFamily:"ARM", deviceId:".*LM3.*", toolChain:"GNU"},
];

var filterStellarisM4GNU = [
    {deviceFamily:"ARM", deviceId:".*LM4.*", toolChain:"GNU"},
    {deviceFamily:"ARM", deviceId:".*TM4C.*", toolChain:"GNU"},
    {deviceFamily:"ARM", deviceId:".*TM4E.*", toolChain:"GNU"},
];

var filterTiva = [
    {deviceFamily:"ARM", deviceId:".*TM4L.*", toolChain:"TI"},
    {deviceFamily:"ARM", deviceId:".*LM4.*", toolChain:"TI"},
    {deviceFamily:"ARM", deviceId:".*TM4C.*", toolChain:"TI"},
    {deviceFamily:"ARM", deviceId:".*TM4E.*", toolChain:"TI"},
];

var filterConcertoM3 = [
    {deviceFamily:"ARM", deviceId:".*F28M3.*", toolChain:"TI"},
];

var filterConcertoC28 = [
    {deviceFamily:"C2000", deviceId:".*F28M3.*", toolChain:"TI"},
];

var filterTI816X_DSP = [
    {deviceFamily: "C6000",
     deviceId: ".*(TI816x).*",
     toolChain:"TI"},
];

/*
 *  TODO: This should filter out everything but TI816X M3. As it is,
 *  the Cortex A is not filtered out.
 */
var filterTI816X_M3 = [
    {deviceFamily: "ARM", deviceId: ".*(TI816x).*", toolChain:"TI"},
];

var filterC6472 = [
    {deviceFamily:"C6000", deviceId:".*6472.*", toolChain:"TI"},
];

/*
 * linkerCommandFile is used below since CCS/project wizard does not allow the
 * use of linkerCommandFile like we'd like.  The workaround is to provide
 * the .cmd file in the fileList[] array and set linkerCommandFile to "".
 */
var options = [
    /* Generics */
    {
        variant: "genericARM",
        filter: filterGenericARM,
        cfgPrefix: "",
        linkerCommandFile: "",
        compilerBuildOptions: "",
        linkerBuildOptions: ""
    },
    {
        variant: "genericC6000",
        filter: filterGenericC6000,
        cfgPrefix: "",
        linkerCommandFile: "",
        compilerBuildOptions: "",
        linkerBuildOptions: ""
    },
    {
        variant: "a8",
        filter: filterA8,
        cfgPrefix: "",
        linkerCommandFile: "",
        compilerBuildOptions: "",
        linkerBuildOptions: ""
    },
    /* A8 GNU */
    {
        variant: "a8GNU",
        filter: filterA8GNU,
        cfgPrefix: "",
        target: "gnu.targets.arm.A8F",
        linkerCommandFile: "",
        compilerBuildOptions: "-mfloat-abi=hard",
        linkerBuildOptions: "-nostartfiles -static --gc-sections -lgcc -lc -lm -lnosys -L${XDC_CG_ROOT}/packages/gnu/targets/arm/libs/install-native/arm-none-eabi/lib/fpu"
    },
    /* C28 */
    {
        variant: "c28",
        filter: filterC28,
        cfgPrefix: "small/",
        platform: "ti.platforms.tms320x28:$DeviceId$",
        linkerCommandFile: "ti/platforms/tms320x28/include/$DeviceId$.cmd",
        compilerBuildOptions: "",
        linkerBuildOptions: "",
    },
    /* MSP430 */
    {
        variant: "msp430",
        filter: filterMSP430,
        cfgPrefix: "msp430/",
        platform: "ti.platforms.msp430:$DeviceId$",
        compilerBuildOptions: "",
        linkerBuildOptions: ""
    },
    /* Stellaris M3 */
    {
        variant: "stellarisM3",
        filter: filterStellaris,
        cfgPrefix: "small/",
        platform: "ti.platforms.stellaris:$DeviceId$",
        compilerBuildOptions: "",
        linkerBuildOptions: "",
    },
    /* Stellaris M3 GNU - Not ready yet.
    {
        variant: "m3GNU",
        filter: filterStellarisM3GNU,
        cfgPrefix: "",
        target: "gnu.targets.arm.M3",
        platform: "ti.platforms.stellaris:$DeviceId$",
        compilerBuildOptions: "-mthumb -march=armv7-m",
        linkerBuildOptions: "-nostartfiles -static --gc-sections -lgcc -lc -lm -L${XDC_CG_ROOT}/packages/gnu/targets/arm/libs/install-native/arm-none-eabi/lib/armv7-m"
    }, */
    /* Stellaris M4 GNU - Not ready yet.
    {
        variant: "m4GNU",
        filter: filterStellarisM4GNU,
        cfgPrefix: "",
        target: "gnu.targets.arm.M4F",
        platform: "ti.platforms.stellaris:$DeviceId$",
        compilerBuildOptions: "-mthumb -march=armv7e-m -mfloat-abi=hard -mfpu=fpv4-sp-d16",
        linkerBuildOptions: "-nostartfiles -static --gc-sections -lgcc -lc -lm -L${XDC_CG_ROOT}/packages/gnu/targets/arm/libs/install-native/arm-none-eabi/lib/armv7e-m/fpu",
    }, */
    /* TIVA */
    {
        variant: "tivaM4",
        filter: filterTiva,
        cfgPrefix: "small/",
        platform: "ti.platforms.tiva:$DeviceId$",
        compilerBuildOptions: "",
        linkerBuildOptions: ""
    },
    /* Concerto C28 */
    {
        variant: "c28Concerto",
        filter: filterConcertoC28,
        cfgPrefix: "small/",
        platform: "ti.platforms.concertoC28:$DeviceId$",
        linkerCommandFile: "ti/platforms/concertoC28/include/$DeviceId$.cmd",
        compilerBuildOptions: "",
        linkerBuildOptions: "",
    },
    /* Concerto M3 */
    {
        variant: "m3",
        filter: filterConcertoM3,
        cfgPrefix: "small/",
        platform: "ti.platforms.concertoM3:$DeviceId$",
        linkerCommandFile: "ti/platforms/concertoM3/include/$DeviceId$.cmd",
        compilerBuildOptions: "",
        linkerBuildOptions: "",
    },
    /* TI816X DSP */
    {
        variant: "ti816xDSP",
        filter: filterTI816X_DSP,
        cfgPrefix: "",
        target: "ti.targets.elf.C674",
        platform: "ti.uia.examples.platforms.evmTI816X.dsp",
        linkerCommandFile: "",
        compilerBuildOptions: "",
        linkerBuildOptions: "",
    },
    /* c6472 */
    {
        variant: "c6472",
        filter: filterC6472,
        cfgPrefix: "",
        target: "ti.targets.C64P",
        platform: "ti.platforms.evm6472",
        linkerCommandFile: "",
        compilerBuildOptions: "",
        linkerBuildOptions: "",
    },
];

//if (0) {
/*
 *  Skip these for now until we figure out how to filter out everything
 *  but TI816X M3.
 */
    /* TI816X videoM3 */
//    {
//        variant: "videoM3",
//        filter: filterTI816X_M3,
//        cfgPrefix: "",
//        target: "ti.targets.arm.elf.M3",
//        platform: "ti.uia.examples.platforms.evmTI816X.video",
//    },
    /* TI816X vpssM3 */
//    {
//        variant: "vpssM3",
//        filter: filterTI816X_M3,
//        cfgPrefix: "",
//        target: "ti.targets.arm.elf.M3",
//        platform: "ti.uia.examples.platforms.evmTI816X.vpss",
//    },
//}

var singleCoreExamples = [
    {
        groups:["ti.uia.examples.root.singlecore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "Stairstep JTAG StopMode",
        name: "stairstepStopMode",
        description: "The stairstep example runs continuously and periodically generates log events. Different threads (Hwi, Swi, Task) run to present a CPU load to the system.  The Log data is obtained when the target is halted.  The sizes of the loggers in LoggingSetup might need to be decreased if your target does not have enough memory.",
        root: "./single/",
        cFile: "stairstep.c",
        cfgFile: "stairstep_JTAGStopMode.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
/*
    {
        groups:["ti.uia.examples.root.singlecore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "LoggerStreamer Example",
        description: "Example showing the usage of LoggerStreamer and LogUC.h",
        root: "./single/",
        cFile: "logger.c",
        cfgFile: "logger.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
*/
    {
        groups:["ti.uia.examples.root.singlecore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "Stairstep ProbePoint",
        name: "stairstepProbePoint",
        description: "The stairstep example runs continuously and periodically generates log events. Different threads (Hwi, Swi, Task) run to present a CPU load to the system.  The Log data is obtained by temporarily stopping the target when the Log call is made.  The sizes of the loggers in LoggingSetup might need to be decreased if your target does not have enough memory.",
        root: "./single/",
        cFile: "stairstep.c",
        cfgFile: "stairstep_ProbePoint.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
/*
 *  We can run Stairstep JTAG StopMode and Stairstep ProbePoint on
 *  the simulator, so there is no need for this example.  It is identical
 *  to Stairstep ProbePoint.
    {
        groups:["ti.uia.examples.root.singlecore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "Stairstep Simulator",
        description: "The stairstep example runs continuously and periodically
    generates log events. Different threads (Hwi, Swi, Task) run to present a
    CPU load to the system. The Log data is obtained by temporarily stopping
    the target when the Log call is made.  The sizes of the loggers in
    LoggingSetup might need to be decreased if your target does not have enough
    memory.",
        root: "./single/",
        cFile: "stairstep.c",
        cfgFile: "stairstep_Simulator.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
*/
];

var NDKExamples = [
    {
        groups:["ti.uia.examples.root.singlecore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "Stairstep Ethernet",
        name: "stairstepEthernet",
        description: "The stairstep example runs continuously and periodically generates log events. Different threads (Hwi, Swi, Task) run to present a CPU load to the system. Log data is obtained via Ethernet. The sizes of the loggers in LoggingSetup might need to be decreased if your target does not have enough memory.  This example, as is, only works for the EVM6472 board. Refer to the bottom of the .cfg file on how to use on a different board.",
        root: "./single/",
        cFile: "stairstep.c",
        cfgFile: "stairstep_Ethernet.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.NDK" ],
        options: "NPW,TREX",
    },
];

var MessageQExamples = [
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "MessageQ (single image for all cores)",
        name: "MessageQ",
        description: "The message example shows how to use MessageQ on EVM6472 and UIA. It is a single-image example that must be loaded on all cores. A message is sent from core 0 to core 1 to core 2...back to core 0. The UIABenchmark_start and stop is used on core 0 to determine the duration of a round trip. The Log data is obtained via Ethernet.",
        root: "./evm6472/",
        cFile: "message.c",
        cfgFile: "message.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.NDK", "com.ti.rtsc.IPC" ],
        options: "NPW,TREX",
    },
];

var EVMTI816X_DSPExamples = [
    // LoggerCircBuf example. Note: TREX uses the title in the project
    // name, so it should not be too long.  Also, embeded quotes in the
    // description will cause examples to not show up in TREX (TI Resource
    // Explorer)
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "evmti816x: SimpleTask with LoggerCircBuf for the DSP",
        name: "loggerCircBufDSP",
        description: "This DSP example uses LoggerCircBuf to log benchmark events. The events are routed through the ServiceMgr on Linux. The program benchmarks the duration to run an algorithm. Refer to the Getting Started Guide for a more detailed description.",
        root: "./evmti816x/",
        cFile: "simpleTask.c",
        cfgFile: "dspLoggerCircBuf.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.IPC"],
        options: "NPW,TREX",
    },
    // LoggerSM example
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "evmti816x: SimpleTask with LoggerSM for the DSP",
        name: "loggerSMDSP",
        description: "This DSP example uses LoggerSM to log benchmark events. The events can be displayed to the Linux console or written to a binary file. The program benchmarks the duration to run an algorithm. Refer to the Getting Started Guide for a more detailed description.",
        root: "./evmti816x/",
        cFile: "simpleTask.c",
        cfgFile: "dspLoggerSM.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.IPC"],
        options: "NPW,TREX",
    },
];

var EVMTI816X_VideoM3Examples = [
    // LoggerCircBuf example - video M3
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "evmti816x: SimpleTask with LoggerCircBuf for the video M3",
        name: "loggerCircBufVideoM3",
        description: "This Video M3 example uses LoggerCircBuf to log benchmark events. The events are routed through the ServiceMgr on Linux. The program benchmarks the duration to run an algorithm. Refer to the Getting Started Guide for a more detailed description.",
        root: "./evmti816x/",
        cFile: "simpleTask.c",
        cfgFile: "videoM3LoggerCircBuf.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.IPC"],
        options: "NPW,TREX",
    },
    // LoggerSM example - video M3
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "evmti816x: SimpleTask with LoggerSM for the video M3",
        name: "loggerSMVideoM3",
        description: "This Video M3 example uses LoggerSM to log benchmark events. The events can be displayed to the Linux console or written to a binary file. The program benchmarks the duration to run an algorithm. Refer to the Getting Started Guide for a more detailed description.",
        root: "./evmti816x/",
        cFile: "simpleTask.c",
        cfgFile: "videoM3LoggerSM.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.IPC"],
        options: "NPW,TREX",
    },
];

var EVMTI816X_VpssM3Examples = [
    // LoggerCircBuf example - vpss M3
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "evmti816x: SimpleTask with LoggerCircBuf for the vpss M3",
        name: "loggerCircBufVpssM3",
        description: "This VPSS M3 example uses LoggerCircBuf to log benchmark events. The events are routed through the ServiceMgr on Linux. The program benchmarks the duration to run an algorithm. Refer to the Getting Started Guide for a more detailed description.",
        root: "./evmti816x/",
        cFile: "simpleTask.c",
        cfgFile: "vpssM3LoggerCircBuf.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.IPC"],
        options: "NPW,TREX",
    },
    // LoggerSM example - vpss M3
    {
        groups:["ti.uia.examples.root.multicore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.multicoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.multicoreGNU"],
        title: "evmti816x: SimpleTask with LoggerSM for the vpss M3",
        name: "loggerSMVpssM3",
        description: "This VPSS M3 example uses LoggerSM to log benchmark events. The events can be displayed to the Linux console or written to a binary file. The program benchmarks the duration to run an algorithm. Refer to the Getting Started Guide for a more detailed description.",
        root: "./evmti816x/",
        cFile: "simpleTask.c",
        cfgFile: "vpssM3LoggerSM.cfg",
        fileList: [],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS", "com.ti.rtsc.IPC"],
        options: "NPW,TREX",
    },
];

var tutorialsGeneric = [
    {
        groups:["ti.uia.examples.root.tutorials"],
        groupsTI: ["ti.uia.examples.root.targetsTI.tutorialsTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.tutorialsGNU"],
        title: "System Analyzer and UIA Tutorial 1",
        name: "uiaTutorial_1",
        description: "This tutorial shows how to log errors, warnings and info events, benchmark code and control which events are logged. Refer to http://processors.wiki.ti.com/index.php/McsaTutorial1 for more details.",
        root: "./tutorial1/",
        cFile: "main.c",
        cfgFile: "systemAnalyzerTutorial1.cfg",
        fileList: ["tutorial1a.c", "tutorial1b.c", "tutorial1c.c",
                "tutorial1d.c", "systemAnalyzerTutorial1.gel"],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
];

var examplesC6000 = [
    // JTAG RunMode
    {
        groups:["ti.uia.examples.root.singlecore"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "Stairstep JTAG RunMode",
        name: "stairstepRunMode",
        root: "./single/",
        cFile: "stairstep.c",
        cfgFile: "stairstep_JTAGRunMode.cfg",
        fileList: [],
        description: "The stairstep example runs continuously and periodically generates log events. Different threads (Hwi, Swi, Task) run to present a CPU load to the system. The Log data is obtained by reading the running target (only works on C64X+ and C66 CPUs). The sizes of the loggers in LoggingSetup might need to be decreased if your target does not have enough memory.",
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
    // Tutorial 2
    {
        groups:["ti.uia.examples.root.tutorials"],
        groupsTI: ["ti.uia.examples.root.targetsTI.singlecoreTI"],
        groupsGNU: ["ti.uia.examples.root.targetsGNU.singlecoreGNU"],
        title: "System Analyzer and UIA Tutorial 2",
        name: "uiaTutorial_2",
        description: "This tutorial shows how to log data that can be graphed and analyzed for min/max/average statistics.  Also demonstrates how to use LoggerCircBuf and JTAG Run-Mode to upload events while a target is running . Refer to http://processors.wiki.ti.com/index.php/McsaTutorial2 for more details.",
        root: "./tutorial2/",
        cFile: "main.c",
        cfgFile: "systemAnalyzerTutorial2.cfg",
        fileList: ["systemAnalyzerTutorial2.gel"],
        isHybrid: true,
        requiredProducts: [ "com.ti.rtsc.SYSBIOS" ],
        options: "NPW,TREX",
    },
];



var c28Examples = [
    /* c28 specific examples */
]

var msp430Examples = [
    /* MSP430 specific examples */
]


/*
 *  ======== module$meta$init ========
 */
function module$meta$init()
{
    var Examples = this;
    var curGroup = "";

    makeFilterMSP430();

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root",
        name        : "System Analyzer (UIA)",
        description : "System Analyzer (UIA) Tutorials, Templates and Examples"
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.singlecore",
        name        : "Single-core Examples",
        description : "System Analyzer (UIA) Single-core Examples",
        groups      : ["ti.uia.examples.root"]
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.multicore",
        name        : "Multi-core Examples",
        description : "System Analyzer (UIA) Multi-core Examples",
        groups      : ["ti.uia.examples.root"]
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.tutorials",
        name        : "Tutorials",
        description : "System Analyzer (UIA) Tutorials",
        groups      : ["ti.uia.examples.root"]
    });

    /* Enable this code when GNU target builds are working */
if (1) {
    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsTI",
        name        : "TI Target Examples",
        description : "System Analyzer (UIA) Examples for TI targets.",
        groups      : ["ti.uia.examples.root"],
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsGNU",
        name        : "GNU Target Examples",
        description : "System Analyzer (UIA) Examples for GNU targets.",
        groups      : ["ti.uia.examples.root"],
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsTI.singlecoreTI",
        name        : "Single-core Examples",
        description : "System Analyzer (UIA) Single-core Examples",
        groups      : ["ti.uia.examples.root.targetsTI"],
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsGNU.singlecoreGNU",
        name        : "Single-core Examples",
        description : "System Analyzer (UIA) Single-core Examples",
        groups      : ["ti.uia.examples.root.targetsGNU"],
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsTI.multicoreTI",
        name        : "Multi-core Examples",
        description : "System Analyzer (UIA) Multi-core Examples",
        groups      : ["ti.uia.examples.root.targetsTI"]
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsGNU.multicoreGNU",
        name        : "Multi-core Examples",
        description : "System Analyzer (UIA) Multi-core Examples",
        groups      : ["ti.uia.examples.root.targetsGNU"]
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsTI.tutorialsTI",
        name        : "Tutorials",
        description : "System Analyzer (UIA) Tutorials",
        groups      : ["ti.uia.examples.root.targetsTI"]
    });

    Examples.templateGroupArr.$add({
        id          : "ti.uia.examples.root.targetsGNU.tutorialsGNU",
        name        : "Tutorials",
        description : "System Analyzer (UIA) Tutorials",
        groups      : ["ti.uia.examples.root.targetsGNU"]
    });
}
    for (var i = 0; i < options.length; i++) {
        // Single core examples - Add these for all options, except for the
        // ones whose filters overlap with "generic". This prevents them
        // from being added multiple times.
        //if (!options[i].variant.match(/ti816xDSP|videoM3|vpssM3|genericC6000|c6472/)) {
        //    addExamples(Examples, options[i], singleCoreExamples);
        //    addExamples(Examples, options[i], tutorialsGeneric);
        //}

        if (options[i].variant.match(/GNU/)) {
            /* GNU ARM targets */
            curGroup = "GNU";
        }
        else if ((options[i].variant == "a8") ||
                (options[i].variant == "stellarisM3") ||
                (options[i].variant == "tivaM4")) {
            /* TI ARM targets */
            curGroup = "TI";
        }
        else {
            curGroup = "";
        }
        print("****** curGroup = " + curGroup + " ****** variant = " + options[i].variant);

        /*
         *  Add single core examples for all options. The filters for the
         *  options must not overlap, or these examples will be added
         *  twice. The videoM3 and vpssM3 options for TI816X use the same
         *  filter, though, so we have to handle that case.
         */
        if (!options[i].variant.match(/vpssM3/)) {
            addExamples(Examples, options[i], singleCoreExamples, curGroup);
            addExamples(Examples, options[i], tutorialsGeneric, curGroup);
        }

        if (options[i].variant.match(/genericC6000|c6472|ti816xDSP/)) {
            addExamples(Examples, options[i], examplesC6000, curGroup);
        }

        /* Add NDK examples for generic and m3 (Stellaris, Concerto) */
        if (options[i].variant == "c6472") {
            addExamples(Examples, options[i], NDKExamples, curGroup);
            addExamples(Examples, options[i], MessageQExamples, curGroup);
        }

        /* Add c28 specific examples */
        if (options[i].variant == "c28") {
            addExamples(Examples, options[i], c28Examples, curGroup);
        }

        /* Add MSP430 specific examples */
        if (options[i].variant == "msp430") {
            addExamples(Examples, options[i], msp430Examples, curGroup);
        }

        // Add the TI816X examples
        if (options[i].variant == "ti816xDSP") {
            addExamples(Examples, options[i], EVMTI816X_DSPExamples, curGroup);
        }

        if (options[i].variant == "videoM3") {
            addExamples(Examples, options[i], EVMTI816X_VideoM3Examples, curGroup);
        }

        if (options[i].variant == "vpssM3") {
            addExamples(Examples, options[i], EVMTI816X_VpssM3Examples, curGroup);
        }
    }

    /* add common properties shared by all examples */
    for (var i = 0; i < Examples.templateArr.length; i++) {
        var ex = Examples.templateArr[i];

        /* add debugability to all examples using TI toolchain */
        var debug = true;
        for (var j = 0; j < ex.filterArr.length; j++) {
            if (ex.filterArr[j].toolChain != "TI") {
                debug = false;
            }
        }
        if (debug) {
            ex.configuroOptions =
                "--compileOptions &quot;-g --optimize_with_debug&quot;";
        }
    }
}

/*
 *  ======== addExamples ========
 */
function addExamples(Examples, opts, examples, curGroup)
{
    for (var j = 0; j < examples.length; j++) {

        var group = examples[j].groups;
        if (curGroup.match(/TI/)) {
            group = examples[j].groupsTI;
        }
        else if (curGroup.match(/GNU/)) {
            group = examples[j].groupsGNU;
        }

        Examples.templateArr.$add({
                buildProfile: "release",
                filterArr: opts.filter,
                target: opts.target,
                platform: opts.platform,
                linkerCommandFile: opts.linkerCommandFile,
                compilerBuildOptions: opts.compilerBuildOptions,
                linkerBuildOptions: opts.linkerBuildOptions,
                title: examples[j].title,
                name: examples[j].name,
                description: examples[j].description,
                fileList: [
                    {path: examples[j].root + examples[j].cFile},
                    {path: examples[j].root + opts.cfgPrefix +
                               examples[j].cfgFile}
                ],
                isHybrid: examples[j].isHybrid,
                groups: group,
                requiredProducts: examples[j].requiredProducts,
                options: examples[j].options,
            });

        var ex = Examples.templateArr[Examples.templateArr.length - 1];

        /* Add any aditional files to the list */
        for (k = 0; k < examples[j].fileList.length; k++) {
            ex.fileList.$add({path: examples[j].root + examples[j].fileList[k]});
        }
    }
}

/*
 *  ======== makeFilterMSP430 ========
 *  Generate the MSP430 filter based on the devices listed in msp430Settings.xs.
 */
function makeFilterMSP430()
{
    try {
        var msp430 =
            xdc.loadCapsule("ti/sysbios/family/msp430/msp430Settings.xs");

        var devices = msp430.devices[0];

        for (var i = 1; i < msp430.devices.length; i++) {
            devices += "|" + msp430.devices[i];
        }
        filterMSP430.push({deviceId:devices, toolChain:"TI"});
    }
    catch (e) {
        filterMSP430 = defaultFilterMSP430;
    }
}
